# main.py
import machine
import socket
import time
from wifi import WifiSTA


## Pins
PIN_UP = 14 # D5
PIN_LE = 12 # D6
PIN_RI = 13 # D7
# PIN_DN = 16 # D0 - does not support pull
PIN_DN =  2 # D4
PIN_B1 =  0 # D2
PIN_B2 =  4 # D3
## Delay
DELAY_CMD = 0.1
DELAY_IRQ = 0.1
## HOST
RX_ADDR = ("192.168.11.220", 80)
# RX_ADDR = ("192.168.0.1", 80)

ts_irq = 0
s = None

def handle_btn_up(pin):
    global ts_irq
    t = time.time()
    if t > (ts_irq + DELAY_IRQ):
        ts_irq = t
        send_cmd("rotate")

# def handle_btn_b1(pin):
#     global ts_irq
#     t = time.time()
#     if t > (ts_irq + DELAY_IRQ):
#         ts_irq = t
#         send_cmd("b1")

# def handle_btn_b2(pin):
#     global ts_irq
#     t = time.time()
#     if t > (ts_irq + DELAY_IRQ):
#         ts_irq = t
#         send_cmd("b2")

def send_cmd(cmd):
    global s
    print("cmd: {}".format(cmd))
    try:
        s.sendto(cmd.encode(), RX_ADDR)
    except Exception as ex:
        print("Exception Type:{}, args: {}".format(type(ex).__name__, ex.args))

def main():
    global s
    wifiSTA = WifiSTA()
    ## initialize buttons and IRQs
    btn_up = machine.Pin(PIN_UP, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_up.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_up)
    btn_dn = machine.Pin(PIN_DN, machine.Pin.IN, machine.Pin.PULL_UP)
    # btn_dn.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_dn)
    btn_le = machine.Pin(PIN_LE, machine.Pin.IN, machine.Pin.PULL_UP)
    # btn_le.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_le)
    btn_ri = machine.Pin(PIN_RI, machine.Pin.IN, machine.Pin.PULL_UP)
    # btn_ri.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_ri)
    btn_b1 = machine.Pin(PIN_B1, machine.Pin.IN, machine.Pin.PULL_UP)
    # btn_b1.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_b1)
    btn_b2 = machine.Pin(PIN_B2, machine.Pin.IN, machine.Pin.PULL_UP)
    # btn_b2.irq(trigger=machine.Pin.IRQ_FALLING, handler=handle_btn_b2)
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

    while True:
        if not btn_le.value():
            send_cmd("left")
        elif not btn_ri.value():
            send_cmd("right")
        elif not btn_b1.value():
            send_cmd("accel")
        elif not btn_b2.value():
            send_cmd("decel")
        elif not btn_up.value():
            send_cmd("rotate")
        elif not btn_dn.value():
            send_cmd("stop")

        time.sleep(DELAY_CMD)

if __name__ == "__main__":
    main()